@@ -1,7 +1,7 @@
 from pymusement.attraction import Attraction
 class Ride(Attraction):
 
-    _added_keys = ['wait', 'isOpen', 'single_rider', 'virtual_line']
+    _added_keys = ['wait', 'isOpen', 'status', 'single_rider', 'virtual_line']
 
     def __init__(self):
         super(Ride, self).__init__()
@@ -12,7 +12,8 @@ class Ride(Attraction):
 
     def setClosed(self):
         self['isOpen'] = False
-
+    def setStatus(self, status):
+        self['status'] = status
     def setTime(self, time):
         if(isinstance(time, str)):
             time = int(time)
